@@ -23,11 +23,50 @@ except:
 try:
     from osgeo import gdal
 except:
+    #TODO set env conda env ไม่รู้จัก path
     raise ModuleNotFoundError('1.You have to install gdal first with this command "conda install -c conda-forge gdal" 2.pip install lazyearth again')
+import os
+from keras import Sequential
+from keras.layers import Convolution2D
 
 class objearth():
     def __init__(self):
         pass
+    def load_data(rgb):
+        x = []
+        x.append(rgb)
+        return numpy.array(x)
+    def get_model(Xaxis,Yaxis):
+        h5_dir = os.path.join(os.path.dirname(__file__), 'models')
+        weights_path = os.path.join(h5_dir,'weights.h5')
+        model = Sequential()
+        model.add(
+            Convolution2D(
+                32, 9, activation="relu", input_shape=(Xaxis, Yaxis, 3), padding="same"
+            )
+        )
+        model.add(Convolution2D(16, 5, activation="relu", padding="same"))
+        model.add(Convolution2D(3, 5, activation="relu", padding="same"))
+        if weights_path:
+            model.load_weights(weights_path)
+        model.compile(optimizer="adam", loss="mse", metrics=["accuracy"])
+        return model
+    def superresolution(rgb):
+        # model_weights_path = r"C:\Users\tul\Desktop\models\weights.h5"
+        Xa,Ya,_ = rgb.shape
+        model = objearth.get_model(Xa,Ya)                #Prepare model
+        x = objearth.load_data(rgb)
+        out_array = model.predict(x)
+        for index in range(out_array.shape[0]):
+            num, rows, cols, channels = out_array.shape
+            for i in range(rows):
+                for j in range(cols):
+                    for k in range(channels):
+                        if out_array[index][i][j][k] > 1.0:
+                            out_array[index][i][j][k] = 1.0
+            # out_img = Image.fromarray(np.uint8(out_array[0] * 255))
+            out_img = numpy.uint8(out_array[0] * 255)
+        return out_img
     @staticmethod
     def montage(img1,img2):
         """
@@ -1421,7 +1460,7 @@ class imagedataset(objearth,water):
         """
         self.ids = image_dataset
         print("Done.")
-    #TODO
+    #
     def __str__(self):
         pass
     def detail(self):
